# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ProcessNode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11ProcessNode.proto\x12\x0bProcessNode\x1a\x0c\x43ommon.proto\"+\n\x0breturn_info\x12\x0c\n\x04info\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\x05\x32\x87\x01\n\x0bProcessNode\x12;\n\x0eGetProcessInfo\x12\r.Common.empty\x1a\x18.ProcessNode.return_info\"\x00\x12;\n\x0eGetVersionInfo\x12\r.Common.empty\x1a\x18.ProcessNode.return_info\"\x00\x62\x06proto3')



_RETURN_INFO = DESCRIPTOR.message_types_by_name['return_info']
return_info = _reflection.GeneratedProtocolMessageType('return_info', (_message.Message,), {
  'DESCRIPTOR' : _RETURN_INFO,
  '__module__' : 'ProcessNode_pb2'
  # @@protoc_insertion_point(class_scope:ProcessNode.return_info)
  })
_sym_db.RegisterMessage(return_info)

_PROCESSNODE = DESCRIPTOR.services_by_name['ProcessNode']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RETURN_INFO._serialized_start=48
  _RETURN_INFO._serialized_end=91
  _PROCESSNODE._serialized_start=94
  _PROCESSNODE._serialized_end=229
# @@protoc_insertion_point(module_scope)
