# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SomeIpNode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10SomeIpNode.proto\x12\nSomeIpNode\x1a\x0c\x43ommon.proto\"D\n\x0bsomeip_info\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x15\n\rjson_str_info\x18\x02 \x01(\t\"e\n\x0bservice_tag\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x13\n\x0binstance_id\x18\x02 \x01(\x05\x12\x14\n\x0cservice_type\x18\x03 \x01(\t\x12\x15\n\rservice_state\x18\x04 \x01(\x08\";\n\x13someip_call_context\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\x12\x13\n\x0bstr_context\x18\x01 \x01(\t\"N\n\x17someip_response_context\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x13\n\x0bstr_context\x18\x02 \x01(\t\"d\n\x13someip_service_info\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x12\n\nservice_id\x18\x02 \x01(\x04\x12\x13\n\x0binstance_id\x18\x03 \x01(\r\x12\x0e\n\x06src_ip\x18\x04 \x01(\t\"f\n\x14someip_service_infos\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12.\n\x05infos\x18\x02 \x03(\x0b\x32\x1f.SomeIpNode.someip_service_info\"F\n\x11someip_arxml_json\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x11\n\tjson_data\x18\x03 \x01(\t2\x89\x07\n\nSomeIpNode\x12\x36\n\x10StartSomeIpStack\x12\x10.Common.net_info\x1a\x0e.Common.result\"\x00\x12\x32\n\x0fStopSomeIpStack\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12\x35\n\x0e\x41\x64\x64SomeIpArxml\x12\x11.Common.file_path\x1a\x0e.Common.result\"\x00\x12\x32\n\x0c\x41\x64\x64IfaceInfo\x12\x10.Common.net_info\x1a\x0e.Common.result\"\x00\x12\x31\n\x0cGetIfaceInfo\x12\r.Common.empty\x1a\x10.Common.net_info\"\x00\x12@\n\x0eGetArxmlToJson\x12\r.Common.empty\x1a\x1d.SomeIpNode.someip_arxml_json\"\x00\x12\x41\n\x15GetSomeIpServiceInfos\x12\r.Common.empty\x1a\x17.SomeIpNode.someip_info\"\x00\x12\x46\n\x19UpdateSomeipServiceConfig\x12\x17.SomeIpNode.service_tag\x1a\x0e.Common.result\"\x00\x12(\n\x05Reset\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12X\n\x0eSomeipCallSync\x12\x1f.SomeIpNode.someip_call_context\x1a#.SomeIpNode.someip_response_context\"\x00\x12\x37\n\x14GetSomeipStackStatus\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12G\n\x12GetAllOfferService\x12\r.Common.empty\x1a .SomeIpNode.someip_service_infos\"\x00\x12\x36\n\x08StartLog\x12\x18.Common.folder_file_path\x1a\x0e.Common.result\"\x00\x12\x35\n\x07StopLog\x12\x18.Common.folder_file_path\x1a\x0e.Common.result\"\x00\x12/\n\x0cGetLogStatus\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x62\x06proto3')



_SOMEIP_INFO = DESCRIPTOR.message_types_by_name['someip_info']
_SERVICE_TAG = DESCRIPTOR.message_types_by_name['service_tag']
_SOMEIP_CALL_CONTEXT = DESCRIPTOR.message_types_by_name['someip_call_context']
_SOMEIP_RESPONSE_CONTEXT = DESCRIPTOR.message_types_by_name['someip_response_context']
_SOMEIP_SERVICE_INFO = DESCRIPTOR.message_types_by_name['someip_service_info']
_SOMEIP_SERVICE_INFOS = DESCRIPTOR.message_types_by_name['someip_service_infos']
_SOMEIP_ARXML_JSON = DESCRIPTOR.message_types_by_name['someip_arxml_json']
someip_info = _reflection.GeneratedProtocolMessageType('someip_info', (_message.Message,), {
  'DESCRIPTOR' : _SOMEIP_INFO,
  '__module__' : 'SomeIpNode_pb2'
  # @@protoc_insertion_point(class_scope:SomeIpNode.someip_info)
  })
_sym_db.RegisterMessage(someip_info)

service_tag = _reflection.GeneratedProtocolMessageType('service_tag', (_message.Message,), {
  'DESCRIPTOR' : _SERVICE_TAG,
  '__module__' : 'SomeIpNode_pb2'
  # @@protoc_insertion_point(class_scope:SomeIpNode.service_tag)
  })
_sym_db.RegisterMessage(service_tag)

someip_call_context = _reflection.GeneratedProtocolMessageType('someip_call_context', (_message.Message,), {
  'DESCRIPTOR' : _SOMEIP_CALL_CONTEXT,
  '__module__' : 'SomeIpNode_pb2'
  # @@protoc_insertion_point(class_scope:SomeIpNode.someip_call_context)
  })
_sym_db.RegisterMessage(someip_call_context)

someip_response_context = _reflection.GeneratedProtocolMessageType('someip_response_context', (_message.Message,), {
  'DESCRIPTOR' : _SOMEIP_RESPONSE_CONTEXT,
  '__module__' : 'SomeIpNode_pb2'
  # @@protoc_insertion_point(class_scope:SomeIpNode.someip_response_context)
  })
_sym_db.RegisterMessage(someip_response_context)

someip_service_info = _reflection.GeneratedProtocolMessageType('someip_service_info', (_message.Message,), {
  'DESCRIPTOR' : _SOMEIP_SERVICE_INFO,
  '__module__' : 'SomeIpNode_pb2'
  # @@protoc_insertion_point(class_scope:SomeIpNode.someip_service_info)
  })
_sym_db.RegisterMessage(someip_service_info)

someip_service_infos = _reflection.GeneratedProtocolMessageType('someip_service_infos', (_message.Message,), {
  'DESCRIPTOR' : _SOMEIP_SERVICE_INFOS,
  '__module__' : 'SomeIpNode_pb2'
  # @@protoc_insertion_point(class_scope:SomeIpNode.someip_service_infos)
  })
_sym_db.RegisterMessage(someip_service_infos)

someip_arxml_json = _reflection.GeneratedProtocolMessageType('someip_arxml_json', (_message.Message,), {
  'DESCRIPTOR' : _SOMEIP_ARXML_JSON,
  '__module__' : 'SomeIpNode_pb2'
  # @@protoc_insertion_point(class_scope:SomeIpNode.someip_arxml_json)
  })
_sym_db.RegisterMessage(someip_arxml_json)

_SOMEIPNODE = DESCRIPTOR.services_by_name['SomeIpNode']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SOMEIP_INFO._serialized_start=46
  _SOMEIP_INFO._serialized_end=114
  _SERVICE_TAG._serialized_start=116
  _SERVICE_TAG._serialized_end=217
  _SOMEIP_CALL_CONTEXT._serialized_start=219
  _SOMEIP_CALL_CONTEXT._serialized_end=278
  _SOMEIP_RESPONSE_CONTEXT._serialized_start=280
  _SOMEIP_RESPONSE_CONTEXT._serialized_end=358
  _SOMEIP_SERVICE_INFO._serialized_start=360
  _SOMEIP_SERVICE_INFO._serialized_end=460
  _SOMEIP_SERVICE_INFOS._serialized_start=462
  _SOMEIP_SERVICE_INFOS._serialized_end=564
  _SOMEIP_ARXML_JSON._serialized_start=566
  _SOMEIP_ARXML_JSON._serialized_end=636
  _SOMEIPNODE._serialized_start=639
  _SOMEIPNODE._serialized_end=1544
# @@protoc_insertion_point(module_scope)
