# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LinParserNode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13LinParserNode.proto\x12\rLinParserNode\x1a\x0c\x43ommon.proto\"C\n\x0flin_node_config\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\x05\x12\x0c\n\x04simu\x18\x03 \x01(\x08\"W\n\x10lin_frame_config\x12\x10\n\x08\x66rame_id\x18\x01 \x01(\x05\x12\x12\n\nframe_name\x18\x02 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\x05\x12\x0c\n\x04simu\x18\x04 \x01(\x08\"o\n\x12lin_channel_config\x12\x10\n\x08ldf_path\x18\x01 \x01(\t\x12\x10\n\x08lin_mode\x18\x02 \x01(\t\x12\x0e\n\x06txrecv\x18\x03 \x01(\x05\x12\x10\n\x08\x62\x61udrate\x18\x04 \x01(\x03\x12\x13\n\x0blin_channel\x18\x05 \x01(\x05\"W\n\x11lin_parser_status\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x12\n\nstr_status\x18\x03 \x01(\t\"A\n\x0clin_ldf_json\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x11\n\tjson_data\x18\x03 \x01(\t2\xa7\x04\n\rLinParserNode\x12\x30\n\tAddDbfile\x12\x11.Common.file_path\x1a\x0e.Common.result\"\x00\x12G\n\x10SetChannelConfig\x12!.LinParserNode.lin_channel_config\x1a\x0e.Common.result\"\x00\x12\x45\n\x11SetNodeSimulation\x12\x1e.LinParserNode.lin_node_config\x1a\x0e.Common.result\"\x00\x12G\n\x12SetFrameSimulation\x12\x1f.LinParserNode.lin_frame_config\x1a\x0e.Common.result\"\x00\x12(\n\x05\x43lear\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12\x31\n\x0e\x43learSubscribe\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12.\n\x0b\x43learDbfile\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12>\n\tGetStatus\x12\r.Common.empty\x1a .LinParserNode.lin_parser_status\"\x00\x12>\n\x0eGetLdfJsonTree\x12\r.Common.empty\x1a\x1b.LinParserNode.lin_ldf_json\"\x00\x62\x06proto3')



_LIN_NODE_CONFIG = DESCRIPTOR.message_types_by_name['lin_node_config']
_LIN_FRAME_CONFIG = DESCRIPTOR.message_types_by_name['lin_frame_config']
_LIN_CHANNEL_CONFIG = DESCRIPTOR.message_types_by_name['lin_channel_config']
_LIN_PARSER_STATUS = DESCRIPTOR.message_types_by_name['lin_parser_status']
_LIN_LDF_JSON = DESCRIPTOR.message_types_by_name['lin_ldf_json']
lin_node_config = _reflection.GeneratedProtocolMessageType('lin_node_config', (_message.Message,), {
  'DESCRIPTOR' : _LIN_NODE_CONFIG,
  '__module__' : 'LinParserNode_pb2'
  # @@protoc_insertion_point(class_scope:LinParserNode.lin_node_config)
  })
_sym_db.RegisterMessage(lin_node_config)

lin_frame_config = _reflection.GeneratedProtocolMessageType('lin_frame_config', (_message.Message,), {
  'DESCRIPTOR' : _LIN_FRAME_CONFIG,
  '__module__' : 'LinParserNode_pb2'
  # @@protoc_insertion_point(class_scope:LinParserNode.lin_frame_config)
  })
_sym_db.RegisterMessage(lin_frame_config)

lin_channel_config = _reflection.GeneratedProtocolMessageType('lin_channel_config', (_message.Message,), {
  'DESCRIPTOR' : _LIN_CHANNEL_CONFIG,
  '__module__' : 'LinParserNode_pb2'
  # @@protoc_insertion_point(class_scope:LinParserNode.lin_channel_config)
  })
_sym_db.RegisterMessage(lin_channel_config)

lin_parser_status = _reflection.GeneratedProtocolMessageType('lin_parser_status', (_message.Message,), {
  'DESCRIPTOR' : _LIN_PARSER_STATUS,
  '__module__' : 'LinParserNode_pb2'
  # @@protoc_insertion_point(class_scope:LinParserNode.lin_parser_status)
  })
_sym_db.RegisterMessage(lin_parser_status)

lin_ldf_json = _reflection.GeneratedProtocolMessageType('lin_ldf_json', (_message.Message,), {
  'DESCRIPTOR' : _LIN_LDF_JSON,
  '__module__' : 'LinParserNode_pb2'
  # @@protoc_insertion_point(class_scope:LinParserNode.lin_ldf_json)
  })
_sym_db.RegisterMessage(lin_ldf_json)

_LINPARSERNODE = DESCRIPTOR.services_by_name['LinParserNode']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LIN_NODE_CONFIG._serialized_start=52
  _LIN_NODE_CONFIG._serialized_end=119
  _LIN_FRAME_CONFIG._serialized_start=121
  _LIN_FRAME_CONFIG._serialized_end=208
  _LIN_CHANNEL_CONFIG._serialized_start=210
  _LIN_CHANNEL_CONFIG._serialized_end=321
  _LIN_PARSER_STATUS._serialized_start=323
  _LIN_PARSER_STATUS._serialized_end=410
  _LIN_LDF_JSON._serialized_start=412
  _LIN_LDF_JSON._serialized_end=477
  _LINPARSERNODE._serialized_start=480
  _LINPARSERNODE._serialized_end=1031
# @@protoc_insertion_point(module_scope)
