# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LogReplayNode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13LogReplayNode.proto\x12\rLogReplayNode\x1a\x0c\x43ommon.proto\"e\n\x12lin_message_decode\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\r\x12\n\n\x02id\x18\x03 \x01(\r\x12\x12\n\ndecode_str\x18\x04 \x01(\t\"1\n\x0flin_decode_role\x12\x10\n\x08\x63hannels\x18\x01 \x03(\r\x12\x0c\n\x04ldfs\x18\x02 \x03(\t\"T\n\x0f\x63\x61n_decode_role\x12\x18\n\x10\x63\x61n_db_file_path\x18\x01 \x01(\t\x12\x10\n\x08\x63hannels\x18\x02 \x03(\r\x12\x15\n\rcluster_names\x18\x03 \x03(\t\"0\n\x08\x64\x65\x63ode_n\x12\x15\n\rblf_file_path\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"i\n\rdecode_result\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x13\n\x0bstart_index\x18\x02 \x01(\r\x12\x12\n\nstop_index\x18\x03 \x01(\r\x12\x0f\n\x07is_stop\x18\x04 \x01(\x08\"B\n\rblf_file_info\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x11\n\tfile_info\x18\x02 \x01(\t\"E\n\x0blog_request\x12$\n\tfile_path\x18\x01 \x01(\x0b\x32\x11.Common.file_path\x12\x10\n\x08log_flag\x18\x02 \x01(\r2\xe0\x04\n\rLogReplayNode\x12\x38\n\x08StartLog\x12\x1a.LogReplayNode.log_request\x1a\x0e.Common.result\"\x00\x12\x37\n\x0cGetLogStatus\x12\r.Common.empty\x1a\x16.Common.generic_string\"\x00\x12\x37\n\x07StopLog\x12\x1a.LogReplayNode.log_request\x1a\x0e.Common.result\"\x00\x12<\n\x10\x41\x64\x64LinDecodeRole\x12\x16.Common.generic_string\x1a\x0e.Common.result\"\x00\x12<\n\x10\x41\x64\x64\x43\x61nDecodeRole\x12\x16.Common.generic_string\x1a\x0e.Common.result\"\x00\x12\x46\n\x0bReplayNextN\x12\x17.LogReplayNode.decode_n\x1a\x1c.LogReplayNode.decode_result\"\x00\x12\x35\n\x0eOpenReplayFile\x12\x11.Common.file_path\x1a\x0e.Common.result\"\x00\x12\x36\n\x0f\x43loseReplayFile\x12\x11.Common.file_path\x1a\x0e.Common.result\"\x00\x12\x46\n\x11GetReplayFileInfo\x12\x11.Common.file_path\x1a\x1c.LogReplayNode.blf_file_info\"\x00\x12(\n\x05Reset\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x62\x06proto3')



_LIN_MESSAGE_DECODE = DESCRIPTOR.message_types_by_name['lin_message_decode']
_LIN_DECODE_ROLE = DESCRIPTOR.message_types_by_name['lin_decode_role']
_CAN_DECODE_ROLE = DESCRIPTOR.message_types_by_name['can_decode_role']
_DECODE_N = DESCRIPTOR.message_types_by_name['decode_n']
_DECODE_RESULT = DESCRIPTOR.message_types_by_name['decode_result']
_BLF_FILE_INFO = DESCRIPTOR.message_types_by_name['blf_file_info']
_LOG_REQUEST = DESCRIPTOR.message_types_by_name['log_request']
lin_message_decode = _reflection.GeneratedProtocolMessageType('lin_message_decode', (_message.Message,), {
  'DESCRIPTOR' : _LIN_MESSAGE_DECODE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.lin_message_decode)
  })
_sym_db.RegisterMessage(lin_message_decode)

lin_decode_role = _reflection.GeneratedProtocolMessageType('lin_decode_role', (_message.Message,), {
  'DESCRIPTOR' : _LIN_DECODE_ROLE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.lin_decode_role)
  })
_sym_db.RegisterMessage(lin_decode_role)

can_decode_role = _reflection.GeneratedProtocolMessageType('can_decode_role', (_message.Message,), {
  'DESCRIPTOR' : _CAN_DECODE_ROLE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.can_decode_role)
  })
_sym_db.RegisterMessage(can_decode_role)

decode_n = _reflection.GeneratedProtocolMessageType('decode_n', (_message.Message,), {
  'DESCRIPTOR' : _DECODE_N,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.decode_n)
  })
_sym_db.RegisterMessage(decode_n)

decode_result = _reflection.GeneratedProtocolMessageType('decode_result', (_message.Message,), {
  'DESCRIPTOR' : _DECODE_RESULT,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.decode_result)
  })
_sym_db.RegisterMessage(decode_result)

blf_file_info = _reflection.GeneratedProtocolMessageType('blf_file_info', (_message.Message,), {
  'DESCRIPTOR' : _BLF_FILE_INFO,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.blf_file_info)
  })
_sym_db.RegisterMessage(blf_file_info)

log_request = _reflection.GeneratedProtocolMessageType('log_request', (_message.Message,), {
  'DESCRIPTOR' : _LOG_REQUEST,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.log_request)
  })
_sym_db.RegisterMessage(log_request)

_LOGREPLAYNODE = DESCRIPTOR.services_by_name['LogReplayNode']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LIN_MESSAGE_DECODE._serialized_start=52
  _LIN_MESSAGE_DECODE._serialized_end=153
  _LIN_DECODE_ROLE._serialized_start=155
  _LIN_DECODE_ROLE._serialized_end=204
  _CAN_DECODE_ROLE._serialized_start=206
  _CAN_DECODE_ROLE._serialized_end=290
  _DECODE_N._serialized_start=292
  _DECODE_N._serialized_end=340
  _DECODE_RESULT._serialized_start=342
  _DECODE_RESULT._serialized_end=447
  _BLF_FILE_INFO._serialized_start=449
  _BLF_FILE_INFO._serialized_end=515
  _LOG_REQUEST._serialized_start=517
  _LOG_REQUEST._serialized_end=586
  _LOGREPLAYNODE._serialized_start=589
  _LOGREPLAYNODE._serialized_end=1197
# @@protoc_insertion_point(module_scope)
