# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ShareMemNode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12ShareMemNode.proto\x12\x0cShareMemNode\x1a\x0c\x43ommon.proto2>\n\x0cShareMemNode\x12.\n\nGetVersion\x12\r.Common.empty\x1a\x0f.Common.version\"\x00\x62\x06proto3')



_SHAREMEMNODE = DESCRIPTOR.services_by_name['ShareMemNode']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SHAREMEMNODE._serialized_start=50
  _SHAREMEMNODE._serialized_end=112
# @@protoc_insertion_point(module_scope)
