# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LinStackNode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12LinStackNode.proto\x12\x0cLinStackNode\x1a\x0c\x43ommon.proto\"?\n\x12lin_message_config\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04simu\x18\x02 \x01(\x08\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\x05\"2\n\x11lin_header_config\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\x05\x12\x0c\n\x04simu\x18\x01 \x01(\x08\"1\n\x10lin_message_data\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\x05\"9\n\x10lin_stack_config\x12\x14\n\x0chardwareType\x18\x01 \x01(\t\x12\x0f\n\x07\x61ppName\x18\x02 \x01(\t\"C\n\x11lin_stack_configs\x12.\n\x06\x63onfig\x18\x01 \x03(\x0b\x32\x1e.LinStackNode.lin_stack_config\"V\n\x10lin_stack_status\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x12\n\nstr_status\x18\x03 \x01(\t2\xa6\x04\n\x0cLinStackNode\x12(\n\x05Reset\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12>\n\tSetConfig\x12\x1f.LinStackNode.lin_stack_configs\x1a\x0e.Common.result\"\x00\x12\x30\n\rStartLinStack\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12/\n\x0cStopLinStack\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x12J\n\x14SetMessageSimulation\x12 .LinStackNode.lin_message_config\x1a\x0e.Common.result\"\x00\x12H\n\x13SetHeaderSimulation\x12\x1f.LinStackNode.lin_header_config\x1a\x0e.Common.result\"\x00\x12\x42\n\x0eSetMessageData\x12\x1e.LinStackNode.lin_message_data\x1a\x0e.Common.result\"\x00\x12<\n\tGetStatus\x12\r.Common.empty\x1a\x1e.LinStackNode.lin_stack_status\"\x00\x12\x31\n\x0e\x43learSubscribe\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x62\x06proto3')



_LIN_MESSAGE_CONFIG = DESCRIPTOR.message_types_by_name['lin_message_config']
_LIN_HEADER_CONFIG = DESCRIPTOR.message_types_by_name['lin_header_config']
_LIN_MESSAGE_DATA = DESCRIPTOR.message_types_by_name['lin_message_data']
_LIN_STACK_CONFIG = DESCRIPTOR.message_types_by_name['lin_stack_config']
_LIN_STACK_CONFIGS = DESCRIPTOR.message_types_by_name['lin_stack_configs']
_LIN_STACK_STATUS = DESCRIPTOR.message_types_by_name['lin_stack_status']
lin_message_config = _reflection.GeneratedProtocolMessageType('lin_message_config', (_message.Message,), {
  'DESCRIPTOR' : _LIN_MESSAGE_CONFIG,
  '__module__' : 'LinStackNode_pb2'
  # @@protoc_insertion_point(class_scope:LinStackNode.lin_message_config)
  })
_sym_db.RegisterMessage(lin_message_config)

lin_header_config = _reflection.GeneratedProtocolMessageType('lin_header_config', (_message.Message,), {
  'DESCRIPTOR' : _LIN_HEADER_CONFIG,
  '__module__' : 'LinStackNode_pb2'
  # @@protoc_insertion_point(class_scope:LinStackNode.lin_header_config)
  })
_sym_db.RegisterMessage(lin_header_config)

lin_message_data = _reflection.GeneratedProtocolMessageType('lin_message_data', (_message.Message,), {
  'DESCRIPTOR' : _LIN_MESSAGE_DATA,
  '__module__' : 'LinStackNode_pb2'
  # @@protoc_insertion_point(class_scope:LinStackNode.lin_message_data)
  })
_sym_db.RegisterMessage(lin_message_data)

lin_stack_config = _reflection.GeneratedProtocolMessageType('lin_stack_config', (_message.Message,), {
  'DESCRIPTOR' : _LIN_STACK_CONFIG,
  '__module__' : 'LinStackNode_pb2'
  # @@protoc_insertion_point(class_scope:LinStackNode.lin_stack_config)
  })
_sym_db.RegisterMessage(lin_stack_config)

lin_stack_configs = _reflection.GeneratedProtocolMessageType('lin_stack_configs', (_message.Message,), {
  'DESCRIPTOR' : _LIN_STACK_CONFIGS,
  '__module__' : 'LinStackNode_pb2'
  # @@protoc_insertion_point(class_scope:LinStackNode.lin_stack_configs)
  })
_sym_db.RegisterMessage(lin_stack_configs)

lin_stack_status = _reflection.GeneratedProtocolMessageType('lin_stack_status', (_message.Message,), {
  'DESCRIPTOR' : _LIN_STACK_STATUS,
  '__module__' : 'LinStackNode_pb2'
  # @@protoc_insertion_point(class_scope:LinStackNode.lin_stack_status)
  })
_sym_db.RegisterMessage(lin_stack_status)

_LINSTACKNODE = DESCRIPTOR.services_by_name['LinStackNode']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LIN_MESSAGE_CONFIG._serialized_start=50
  _LIN_MESSAGE_CONFIG._serialized_end=113
  _LIN_HEADER_CONFIG._serialized_start=115
  _LIN_HEADER_CONFIG._serialized_end=165
  _LIN_MESSAGE_DATA._serialized_start=167
  _LIN_MESSAGE_DATA._serialized_end=216
  _LIN_STACK_CONFIG._serialized_start=218
  _LIN_STACK_CONFIG._serialized_end=275
  _LIN_STACK_CONFIGS._serialized_start=277
  _LIN_STACK_CONFIGS._serialized_end=344
  _LIN_STACK_STATUS._serialized_start=346
  _LIN_STACK_STATUS._serialized_end=432
  _LINSTACKNODE._serialized_start=435
  _LINSTACKNODE._serialized_end=985
# @@protoc_insertion_point(module_scope)
